@@ -8,9 +8,12 @@
 #include "drawareamain.h"
 #include "toolbar.h"
 
+#include "skeleton/msgdiag.h"
+
 #include "dbtree/interface.h"
 #include "dbtree/articlebase.h"
 
+#include "jdlib/miscutil.h"
 #include "jdlib/misctime.h"
 
 #include "config/globalconf.h"
@@ -38,7 +41,7 @@ ArticleViewMain::ArticleViewMain( const std::string& url )
 #endif
 
     // オートリロード可
-    SKELETON::View::set_enable_autoreload( true );
+    set_enable_autoreload( true );
 
     setup_view();
 }
@@ -53,9 +56,13 @@ ArticleViewMain::~ArticleViewMain()
     int seen = drawarea()->get_seen_current();
         
 #ifdef _DEBUG    
-        std::cout << "set seen to " << seen << std::endl;
+    std::cout << "set seen to " << seen << std::endl;
 #endif
-        if( seen >= 1 ) get_article()->set_number_seen( seen );
+
+    if( seen >= 1 ) get_article()->set_number_seen( seen );
+
+    // 閉じたタブ履歴更新
+    CORE::core_set_command( "set_history_close", url_article() );
 }
 
 
@@ -84,7 +91,11 @@ void ArticleViewMain::goto_num( int num )
 void ArticleViewMain::reload()
 {
     // オフライン
-    if( ! SESSION::is_online() ) return;
+    if( ! SESSION::is_online() ){
+        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        mdiag.run();
+        return;
+    }
 
     // オートリロードのカウンタを0にする
     View::reset_autoreload_counter();
@@ -157,6 +168,8 @@ void ArticleViewMain::show_view()
         m_show_instdialog = true;
     }
 
+    slot_push_claar_hl();
+
     // 差分 download 開始
     get_article()->download_dat();
     if( get_article()->is_loading() ){
@@ -198,14 +211,14 @@ void ArticleViewMain::update_finish()
 {
     int status = DBTREE::article_status( url_article() );
     std::string str_stat;
-    if( status & STATUS_OLD ) str_stat = "[ DAT落ち or 移転しました ]";
+    if( status & STATUS_OLD ) str_stat = "[ DAT落ち 又は 移転しました ]";
     if( status & STATUS_BROKEN ) str_stat = "[ 壊れています ]";
 
     if( ! DBTREE::article_ext_err( url_article() ).empty() ) str_stat += " [ " + DBTREE::article_ext_err( url_article() ) + " ]";
 
-    // ラベルセット
-    toolbar()->m_button_board.set_label( "[ " + DBTREE::board_name( url_article() ) + " ]" );
-    toolbar()->set_label( str_stat + DBTREE::article_subject( url_article() ) );
+    // 板名とスレ名をセット
+    if( toolbar()->m_button_board.get_label().empty() ) toolbar()->m_button_board.set_label( "[ " + DBTREE::board_name( url_article() ) + " ]" );
+    if( toolbar()->get_label().empty() ) toolbar()->set_label( str_stat + DBTREE::article_subject( url_article() ) );
 
     // タブのラベルセット
     std::string str_label = str_stat + DBTREE::article_subject( url_article() );
@@ -233,11 +246,15 @@ void ArticleViewMain::update_finish()
     std::cout << "ArticleViewMain::update_finish " << str_label << " code = " << code << std::endl;;
 #endif
 
+    // 新着セパレータを消す
+    int number_new = DBTREE::article_number_new( url_article() );
+    if( ! number_new ) drawarea()->hide_separator_new();
+
     // ステータス表示
     std::ostringstream ss_tmp;
     ss_tmp << DBTREE::article_str_code( url_article() )
            << " [ 全 " << DBTREE::article_number_load( url_article() )
-           << " / 新着 " << DBTREE::article_number_new( url_article() );
+           << " / 新着 " << number_new;
 
     if( DBTREE::article_write_time( url_article() ) ) ss_tmp << " / 最終書込 " << DBTREE::article_write_date( url_article() );
 
@@ -245,12 +262,12 @@ void ArticleViewMain::update_finish()
            << " / " << DBTREE::article_lng_dat( url_article() )/1024 << " k ] "
            << str_stat;
 
-    SKELETON::View::set_status( ss_tmp.str() );
-    ARTICLE::get_admin()->set_command( "set_status", get_url(), SKELETON::View::get_status() );
+    set_status( ss_tmp.str() );
+    ARTICLE::get_admin()->set_command( "set_status", get_url(), get_status() );
 
     // タイトルセット
-    SKELETON::View::set_title( DBTREE::article_subject( url_article() ) );
-    ARTICLE::get_admin()->set_command( "set_title", get_url(), SKELETON::View::get_title() );
+    set_title( DBTREE::article_subject( url_article() ) );
+    ARTICLE::get_admin()->set_command( "set_title", get_url(), get_title() );
 
     // 全体再描画
     drawarea()->redraw_view();
@@ -267,7 +284,7 @@ void ArticleViewMain::update_finish()
 //
 void ArticleViewMain::show_instruct_diag()
 {
-    Gtk::MessageDialog mdiag(
+    SKELETON::MsgDiag mdiag( NULL, 
         "スレビューからスレ一覧表示に戻る方法として\n\n(1) マウスジェスチャを使う( 右ボタンを押しながら下にドラッグして離す )\n\n(2) マウスの5ボタンを押す\n\n(3) Alt+x か h か ← を押す\n\n(4) ツールバーのスレ一覧アイコンを押す\n\n(5) 表示メニューからスレ一覧を選ぶ\n\nなどがあります。詳しくはオンラインマニュアルを参照してください。" );
     Gtk::CheckButton chkbutton( "今後表示しない" );
     mdiag.get_vbox()->pack_start( chkbutton, Gtk::PACK_SHRINK );
@@ -290,13 +307,17 @@ void ArticleViewMain::relayout()
     std::cout << "ArticleViewMain::relayout\n";
 #endif
 
+    hide_popup( true );
+
     int seen = drawarea()->get_seen_current();
+    int num_reserve = drawarea()->get_goto_num_reserve();
     int separator_new = drawarea()->get_separator_new();
 
     drawarea()->clear_screen();
-    drawarea()->append_res( 1, get_article()->get_number_load() );
     drawarea()->set_separator_new( separator_new );
-    drawarea()->goto_num( seen );
+    drawarea()->append_res( 1, get_article()->get_number_load() );
+    if( num_reserve ) drawarea()->goto_num( num_reserve );
+    else if( seen ) drawarea()->goto_num( seen );
     drawarea()->redraw_view();
 }
 
@@ -902,7 +923,7 @@ void ArticleViewSearchCache::show_view()
         }
     }
     else if( CORE::get_search_manager()->is_searching() ){
-        Gtk::MessageDialog mdiag( "他の検索スレッドが実行中です" );
+        SKELETON::MsgDiag mdiag( NULL, "他の検索スレッドが実行中です" );
         mdiag.run();
     }
 }
@@ -936,10 +957,12 @@ void ArticleViewSearchCache::relayout()
 
             DBTREE::ArticleBase* article = DBTREE::get_article( *it );
             if( article ){
-                comment << "[ " << DBTREE::board_name( article->get_url() ) << " ] ";
+
+                if( m_searchall ) comment << "[ <a href=\"" << DBTREE::url_subject( article->get_url() ) << "\">"
+                                          << DBTREE::board_name( article->get_url() ) << "</a> ] ";
+                comment << "<a href=\"" << *it << "\">" << article->get_subject() << "</a><br>";
                 comment << "<a href=\"" << PROTO_OR << *it + KEYWORD_SIGN + query << "\">"
-                        << article->get_subject() << "</a><br>";
-                comment << *it << "<br><br>";
+                        << "抽出表示する" << "</a><br><br>";
             }
         }
     }
@@ -973,7 +996,7 @@ void ArticleViewSearchCache::slot_search_fin()
 void ArticleViewSearchCache::reload()
 {
     if( CORE::get_search_manager()->is_searching() ){
-        Gtk::MessageDialog mdiag( "他の検索スレッドが実行中です" );
+        SKELETON::MsgDiag mdiag( NULL, "他の検索スレッドが実行中です" );
         mdiag.run();
     }
 
