@@ -87,6 +87,10 @@ namespace ARTICLE
         virtual void goto_top();
         virtual void goto_bottom();
         virtual void goto_num( int num );
+        virtual void toggle_toolbar();
+
+        // 記事削除 & 再オープン
+        void delete_open_view();
 
     protected:
 
@@ -100,6 +104,9 @@ namespace ARTICLE
         // ポップアップメニュー取得
         virtual Gtk::Menu* get_popupmenu( const std::string& url );
 
+        // レスポップアップを隠す
+        void hide_popup( bool force = false );
+
         // 初期設定
         void setup_view();
 
@@ -147,6 +154,7 @@ namespace ARTICLE
 
         // ツールバーのボタンを押したときのスロット
         void slot_push_close_search();
+        void slot_push_reload();
         void slot_push_write();
         void slot_push_delete();
         void slot_push_open_board();
@@ -170,7 +178,7 @@ namespace ARTICLE
         std::string get_html_url4report( std::list< int >& list_resnum );
         
         // drawarea の signal を受け取る slots
-        bool slot_button_press( GdkEventButton* event );
+        virtual bool slot_button_press( std::string url, int res_number, GdkEventButton* event );
         bool slot_button_release( std::string url, int res_number, GdkEventButton* event );
         bool slot_motion_notify( GdkEventMotion* event );
         bool slot_key_press( GdkEventKey* event );
@@ -186,10 +194,9 @@ namespace ARTICLE
         // ポップアップが表示されていてかつマウスがその上にあるか
         const bool is_mouse_on_popup();
 
-        void show_popup( SKELETON::View* view );
+        void show_popup( SKELETON::View* view, int margin );
         bool slot_popup_leave_notify_event( GdkEventCrossing* event );
         void slot_hide_popup();
-        void hide_popup( bool force = false );
         void delete_popup(); // ポップアップ強制削除
         void warp_pointer_to_popup(); // マウスポインタをポップアップの上に移動する
         
@@ -197,6 +204,7 @@ namespace ARTICLE
         void slot_open_browser();
         void slot_write_res();
         void slot_quote_res();
+        void slot_quote_selection_res();
         void slot_copy_current_url();
         void slot_copy_name();
         void slot_copy_id();
@@ -219,6 +227,8 @@ namespace ARTICLE
         void slot_abone_id();
         void slot_abone_name();
         void slot_abone_word();
+        void slot_abone_name_board();
+        void slot_abone_word_board();
         void slot_global_abone_name();
         void slot_global_abone_word();
         void slot_toggle_abone_transp();
@@ -238,6 +248,7 @@ namespace ARTICLE
         void slot_deleteimage();
         void slot_toggle_protectimage();
         void slot_saveimage();
+        void slot_abone_img();
 
         // 検索
         virtual void open_searchbar( bool invert );
