@@ -7,6 +7,8 @@
 #include "bbslistviewbase.h"
 #include "bbslistadmin.h"
 
+#include "skeleton/msgdiag.h"
+
 #include "jdlib/miscutil.h"
 #include "jdlib/jdregex.h"
 
@@ -25,8 +27,9 @@
 #include "dndmanager.h"
 #include "sharedbuffer.h"
 #include "viewfactory.h"
-#include "xml.h"
 #include "prefdiagfactory.h"
+#include "colorid.h"
+#include "fontid.h"
 
 #include <sstream>
 //#include <gtk/gtkversion.h> // GTK_CHECK_VERSION
@@ -50,7 +53,7 @@
 #define SHOW_POPUPMENU(slot) do{\
 std::string url = path2url( m_path_selected ); \
 if( ! m_path_selected.empty() && url.empty() ) url = "dummy_url"; \
-SKELETON::View::show_popupmenu( url, slot ); \
+show_popupmenu( url, slot ); \
 }while(0)
 
 
@@ -59,7 +62,8 @@ using namespace BBSLIST;
 
 BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1, const std::string& arg2 )
     : SKELETON::View( url ),
-      m_treeview( CONFIG::get_fontname_tree(), CONFIG::get_color_back_tree() ),
+      m_treeview( CONFIG::get_fontname( FONT_BBS ), COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN ),
+      m_toolbar( SESSION::get_show_bbslist_toolbar() ),
       m_ready_tree( false ),
       m_jump_y( -1 ),
       m_dnd_counter( 0 ),
@@ -71,7 +75,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC );
 
-    m_toolbar.m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BBSListViewBase::search ) );
+    m_toolbar.m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_active_search ) );
     m_toolbar.m_button_up_search.signal_clicked().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_push_up_search ) );
     m_toolbar.m_button_down_search.signal_clicked().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_push_down_search ) );
     m_toolbar.m_entry_search.signal_operate().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_entry_operate ) );
@@ -299,10 +303,10 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     CONTROL::set_menu_motion( popupmenu );
 
     // マウスジェスチャ可
-    SKELETON::View::set_enable_mg( true );
+    set_enable_mg( true );
 
     // コントロールモード設定
-    SKELETON::View::get_control().set_mode( CONTROL::MODE_BBSLIST );
+    get_control().add_mode( CONTROL::MODE_BBSLIST );
 }
 
 
@@ -391,8 +395,8 @@ void BBSListViewBase::clock_in()
 //
 void BBSListViewBase::relayout()
 {
-    m_treeview.init_color( CONFIG::get_color_back_tree() );
-    m_treeview.init_font( CONFIG::get_fontname_tree() );
+    m_treeview.init_color( COLOR_CHAR_BBS, COLOR_BACK_BBS, COLOR_BACK_BBS_EVEN );
+    m_treeview.init_font( CONFIG::get_fontname( FONT_BBS ) );
 }
 
 
@@ -407,10 +411,17 @@ void BBSListViewBase::focus_view()
         return;
     }
 
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::focus_view url = " << get_url() << std::endl;
+#endif 
+
     m_treeview.grab_focus();
 
-    if( get_url() == URL_BBSLISTVIEW ) get_toolbar().set_combo( COMBO_BBSLIST );
-    if( get_url() == URL_FAVORITEVIEW ) get_toolbar().set_combo( COMBO_FAVORITE );
+    if( get_url() == URL_BBSLISTVIEW && get_toolbar().get_combo()  != COMBO_BBSLIST )
+        get_toolbar().set_combo( COMBO_BBSLIST );
+
+    else if( get_url() == URL_FAVORITEVIEW && get_toolbar().get_combo() != COMBO_FAVORITE )
+        get_toolbar().set_combo( COMBO_FAVORITE );
 }
 
 
@@ -426,7 +437,9 @@ void BBSListViewBase::focus_out()
 }
 
 
-
+//
+// 閉じる
+//
 void BBSListViewBase::close_view()
 {
     CORE::core_set_command( "toggle_sidebar" );
@@ -524,7 +537,7 @@ void  BBSListViewBase::operate_view( const int& control )
             
         case CONTROL::Delete:
         {
-            Gtk::MessageDialog mdiag( "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+            SKELETON::MsgDiag mdiag( NULL, "削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
             if( mdiag.run() != Gtk::RESPONSE_OK ) return;
             delete_view();
             break;
@@ -563,6 +576,11 @@ void  BBSListViewBase::operate_view( const int& control )
         case CONTROL::ShowSideBar:
             CORE::core_set_command( "toggle_sidebar" );
             break;
+
+            // メニューバー表示/非表示
+        case CONTROL::ShowMenuBar:
+            CORE::core_set_command( "toggle_menubar" );
+            break;
     }
 }
 
@@ -598,7 +616,7 @@ void BBSListViewBase::activate_act_before_popupmenu( const std::string& url )
             break;
 
         case TYPE_IMAGE:
-            if( act_image ) act_image->set_sensitive( true );
+            if( act_image && ! DBIMG::get_abone( url ) ) act_image->set_sensitive( true );
             break;
 
         case TYPE_DIR:
@@ -669,6 +687,15 @@ void BBSListViewBase::page_down()
 } 
 
 
+//
+// ツールバー表示切り替え
+//
+void BBSListViewBase::toggle_toolbar()
+{
+    if( SESSION::get_show_bbslist_toolbar() ) m_toolbar.show_toolbar();
+    else m_toolbar.hide_toolbar();
+}
+
 
 //
 // 他のviewのtreestoreをcopyして表示
@@ -703,16 +730,16 @@ void BBSListViewBase::copy_treestore( Glib::RefPtr< Gtk::TreeStore >& store )
 bool BBSListViewBase::slot_button_press( GdkEventButton* event )
 {
     // マウスジェスチャ
-    SKELETON::View::get_control().MG_start( event );
+    get_control().MG_start( event );
 
     // ホイールマウスジェスチャ
-    SKELETON::View::get_control().MG_wheel_start( event );
+    get_control().MG_wheel_start( event );
 
     // ダブルクリック
     m_dblclick = false;
     if( event->type == GDK_2BUTTON_PRESS ) m_dblclick = true; 
 
-    CORE::core_set_command( "switch_sidebar" );
+    BBSLIST::get_admin()->set_command( "switch_admin" );
 
     return true;
 }
@@ -724,11 +751,11 @@ bool BBSListViewBase::slot_button_press( GdkEventButton* event )
 bool BBSListViewBase::slot_button_release( GdkEventButton* event )
 {
     /// マウスジェスチャ
-    int mg = SKELETON::View::get_control().MG_end( event );
+    int mg = get_control().MG_end( event );
 
     // ホイールマウスジェスチャ
     // 実行された場合は何もしない 
-    if( SKELETON::View::get_control().MG_wheel_end( event ) ) return true;
+    if( get_control().MG_wheel_end( event ) ) return true;
 
     if( mg != CONTROL::None && enable_mg() ){
         operate_view( mg );
@@ -744,8 +771,8 @@ bool BBSListViewBase::slot_button_release( GdkEventButton* event )
     if( m_dblclick ) event->type = GDK_2BUTTON_PRESS;
 
     // 板を開く
-    bool openboard = SKELETON::View::get_control().button_alloted( event, CONTROL::OpenBoardButton );
-    bool openboardtab = SKELETON::View::get_control().button_alloted( event, CONTROL::OpenBoardTabButton );
+    bool openboard = get_control().button_alloted( event, CONTROL::OpenBoardButton );
+    bool openboardtab = get_control().button_alloted( event, CONTROL::OpenBoardTabButton );
     if( openboard || openboardtab ){
 
         // 複数行選択中
@@ -754,7 +781,7 @@ bool BBSListViewBase::slot_button_release( GdkEventButton* event )
         else if( m_treeview.get_row( m_path_selected ) ) open_row( m_path_selected, openboardtab );
     }
     // ポップアップメニューボタン
-    else if( SKELETON::View::get_control().button_alloted( event, CONTROL::PopupmenuButton ) ){
+    else if( get_control().button_alloted( event, CONTROL::PopupmenuButton ) ){
 
         SHOW_POPUPMENU( false );
     }
@@ -775,7 +802,7 @@ bool BBSListViewBase::slot_button_release( GdkEventButton* event )
 bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 {
     /// マウスジェスチャ
-    SKELETON::View::get_control().MG_motion( event );
+    get_control().MG_motion( event );
 
     int x = (int)event->x;
     int y = (int)event->y;
@@ -798,7 +825,7 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 
             m_treeview.hide_tooltip();
 
-            if( DBIMG::is_loadable( url ) && DBIMG::get_code( url ) != HTTP_ERR ){
+            if( DBIMG::is_loadable( url ) && DBIMG::get_code( url ) != HTTP_ERR && DBIMG::get_code( url ) != HTTP_INIT ){
 
                 if( m_treeview.pre_popup_url() != url ){
 
@@ -836,7 +863,7 @@ bool BBSListViewBase::slot_motion_notify( GdkEventMotion* event )
 //
 bool BBSListViewBase::slot_key_press( GdkEventKey* event )
 {
-    int key = SKELETON::View::get_control().key_press( event );
+    int key = get_control().key_press( event );
 
     // キー入力でboardを開くとkey_pressイベントがboadviewに送られて
     // 一番上のスレが開くので、open_row() は slot_key_release() で処理する
@@ -854,16 +881,15 @@ bool BBSListViewBase::slot_key_press( GdkEventKey* event )
 bool BBSListViewBase::slot_key_release( GdkEventKey* event )
 {
 #ifdef _DEBUG
-    guint key = event->keyval;
     bool ctrl = ( event->state ) & GDK_CONTROL_MASK;
     bool shift = ( event->state ) & GDK_SHIFT_MASK;
 
-    std::cout << "BBSListViewBase::slot_key_release key = " << key << " ctrl = " << ctrl << " shift = " << shift << std::endl;
+    std::cout << "BBSListViewBase::slot_key_release key = " << event->keyval << " ctrl = " << ctrl << " shift = " << shift << std::endl;
 #endif
     
     // キー入力でboardを開くとkey_pressイベントがboadviewに送られて
     // 一番上のスレが開くので、open_row() は slot_key_release() で処理する
-    int key = SKELETON::View::get_control().key_press( event );
+    int key = get_control().key_press( event );
     if( key == CONTROL::OpenBoard ) operate_view( key );
     if( key == CONTROL::OpenBoardTab ) operate_view( key );
 
@@ -877,7 +903,7 @@ bool BBSListViewBase::slot_key_release( GdkEventKey* event )
 bool BBSListViewBase::slot_scroll_event( GdkEventScroll* event )
 {
     // ホイールマウスジェスチャ
-    int control = SKELETON::View::get_control().MG_wheel_scroll( event );
+    int control = get_control().MG_wheel_scroll( event );
     if( enable_mg() && control != CONTROL::None ){
         operate_view( control );
         return true;
@@ -1004,7 +1030,8 @@ void BBSListViewBase::slot_rename()
 #endif
 
     m_ren_text->property_editable() = true;     // edit可
-    m_treeview.set_cursor( m_path_selected, *m_treeview.get_column( 0 ), true );
+    m_treeview.set_cursor( m_path_selected, *m_treeview.get_column( COL_NAME ), true );
+
     // メニューが消えるとfocus_viewが呼ばれて名前変更モードが終了するのでfocus_viewをキャンセルする
     m_cancel_focus = true;
     m_ren_text->property_editable() = false;
@@ -1079,7 +1106,7 @@ void BBSListViewBase::slot_preferences_board()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( CORE::PREFDIAG_BOARD, DBTREE::url_subject( url ) );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARD, DBTREE::url_subject( url ) );
     pref->run();
     delete pref;
 }
@@ -1094,7 +1121,7 @@ void BBSListViewBase::slot_preferences_article()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( CORE::PREFDIAG_ARTICLE, DBTREE::url_dat( url ) );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_ARTICLE, DBTREE::url_dat( url ) );
     pref->run();
     delete pref;
 }
@@ -1108,7 +1135,7 @@ void BBSListViewBase::slot_preferences_image()
     if( m_path_selected.empty() ) return;
     std::string url = path2url( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( CORE::PREFDIAG_IMAGE, url );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_IMAGE, url );
     pref->run();
     delete pref;
 }
@@ -1295,14 +1322,19 @@ Gtk::TreeViewColumn* BBSListViewBase::create_column()
 
     m_ren_text = Gtk::manage( new Gtk::CellRendererText() );
     m_ren_text->signal_edited().connect( sigc::mem_fun( *this, &BBSListViewBase::slot_ren_text_on_edited ) );
-    m_ren_text->property_underline().set_value( Pango::UNDERLINE_SINGLE );
+    m_ren_text->property_underline() = Pango::UNDERLINE_SINGLE;
+
+    // 行間スペース
+    m_ren_text->property_ypad() = CONFIG::get_tree_ypad();
 
     col->pack_start( *m_ren_text, true );
-    col->add_attribute( *m_ren_text, "text", 0 );
-    col->add_attribute( *m_ren_text, "underline", 1 );
+    col->add_attribute( *m_ren_text, "text", COL_NAME );
+    col->add_attribute( *m_ren_text, "underline", COL_UNDERLINE );
     col->set_sizing( Gtk::TREE_VIEW_COLUMN_FIXED );
-    col->add_attribute( *m_ren_text, "underline", 1 );
-    
+
+    col->set_cell_data_func( *col->get_first_cell_renderer(), sigc::mem_fun( m_treeview, &SKELETON::JDTreeView::slot_cell_data ) );    
+    col->set_cell_data_func( *m_ren_text, sigc::mem_fun( m_treeview, &SKELETON::JDTreeView::slot_cell_data ) );    
+
     return col;
 }
 
@@ -1335,8 +1367,15 @@ bool BBSListViewBase::open_row( Gtk::TreePath& path, bool tab )
             break;
 
         case TYPE_IMAGE:
-            CORE::core_set_command( "open_image", url );
-            CORE::core_set_command( "switch_image" );
+
+            if( DBIMG::get_abone( url )){
+                SKELETON::MsgDiag mdiag( NULL, "あぼ〜んされています" );
+                mdiag.run();
+            }
+            else{
+                CORE::core_set_command( "open_image", url );
+                CORE::core_set_command( "switch_image" );
+            }
             break;
 
         case TYPE_LINK:
@@ -1652,7 +1691,7 @@ void BBSListViewBase::move_selected_row( const Gtk::TreePath& path, bool after )
         // 移動先がサブディレクトリに含まれないかチェック
         if( is_dir( ( *it_src ) ) ){
             if( path.to_string().find( path_src.to_string() ) != Glib::ustring::npos ){
-                Gtk::MessageDialog mdiag( "移動先は送り側のディレクトリのサブディレクトリです", false, Gtk::MESSAGE_ERROR );
+                SKELETON::MsgDiag mdiag( NULL, "移動先は送り側のディレクトリのサブディレクトリです", false, Gtk::MESSAGE_ERROR );
                 mdiag.run();
                 return;
             }
@@ -1805,7 +1844,7 @@ void BBSListViewBase::delete_selected_rows()
     for( ; it != list_it.end(); ++it ){
 
         if( is_dir( (*it ) ) ){
-            Gtk::MessageDialog mdiag( "ディレクトリを削除すると中のファイルも削除されます。削除しますか？",
+            SKELETON::MsgDiag mdiag( NULL, "ディレクトリを削除すると中のファイルも削除されます。削除しますか？",
                                       false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
             if( mdiag.run() != Gtk::RESPONSE_OK ) return;
 
@@ -1826,190 +1865,102 @@ void BBSListViewBase::delete_selected_rows()
 
 
 
+//
+// 全てのツリーに m_columns.m_expand の値をセットする( tree2xml()で使用 )
+//
+void BBSListViewBase::set_expanded_row( const Gtk::TreeModel::Children& children )
+{
+    Gtk::TreeModel::iterator it = children.begin();
+    while( it != children.end() )
+    {
+        Gtk::TreePath path = m_treestore->get_path( *it );
+
+        // ツリーが開いているか
+        if( m_treeview.row_expanded( path ) ) (*it)[ m_columns.m_expand ] = true;
+        else (*it)[ m_columns.m_expand ] = false;
+
+        // 再帰
+        if( ! (*it)->children().empty() ) set_expanded_row( (*it)->children() );
+
+        ++it;
+    }
+}
+
+
 //
 // tree -> XML 変換
 //
 //
-std::string BBSListViewBase::tree2xml()
+void BBSListViewBase::tree2xml( const std::string& root_name )
 {
-    if( ! m_ready_tree ) return std::string();
-    
+    if( ! m_ready_tree || m_treestore->children().empty() ) return;
+
 #ifdef _DEBUG
     std::cout << "BBSListViewBase::tree2xml\n";
 #endif
 
-    std::stringstream xml;
+    // 全てのツリーに row[ m_columns.expand ] の値をセットする
+    set_expanded_row( m_treestore->children() );
 
-    if( m_treestore->children().empty() ) return std::string();
-    
-    Gtk::TreePath path = GET_PATH( m_treestore->children().begin() );
-    Gtk::TreeModel::Row row;
+    // m_treestore からノードツリーを作成
+    m_document.init( m_treestore, root_name );
+
+#ifdef _DEBUG
+    std::cout << " ルートノード名=" << root_name;
+    std::cout << " 子ノード数=" << m_document.childNodes().size() << std::endl;
+#endif
 
     // 座標
     int y = 0;
     Gtk::Adjustment* adjust = m_treeview.get_vadjustment();
-    if( adjust ){
-
+    if( adjust )
+    {
         if( m_jump_y != -1 && adjust->get_upper() > m_jump_y ) y = m_jump_y;
         else  y = ( int ) adjust->get_value();
     }
     else if( m_jump_y != -1 ) y = m_jump_y;
 
-    xml << "<pos y=\"" << y << "\"";
-
     // 選択中のパス
+    std::string path;
     Gtk::TreeModel::Path focused_path = m_treeview.get_current_path();
-    if( !focused_path.empty() ) xml << " path=\"" << focused_path.to_string() << "\"";
-    xml << "/>\n";
+    if( ! focused_path.empty() ) path = focused_path.to_string();
 
-    while( 1 ){
-
-        if( ( row = m_treeview.get_row( path ) ) ){
-
-            Glib::ustring url = row[ m_columns.m_col_url ];
-            Glib::ustring name = row[ m_columns.m_col_name ];
-            int type = row[ m_columns.m_type ];
-
-            switch( type ){
-
-            case TYPE_DIR: // サブディレクトリ
-                XML_MAKE_DIR(name);
-                path.down();
-                break;
-
-            case TYPE_BOARD: // 板
-                XML_MAKE_BOARD(url,name);
-                path.next();
-                break;
-                
-            case TYPE_THREAD: // スレ
-                XML_MAKE_THREAD(url,name);
-                path.next();
-                break;
-
-            case TYPE_IMAGE: // 画像
-                XML_MAKE_IMAGE(url,name);
-                path.next();
-                break;
-
-            case TYPE_COMMENT: // コメント
-                XML_MAKE_COMMENT(name);
-                path.next();
-                break;
-
-            case TYPE_LINK: // リンク
-                XML_MAKE_LINK(url,name);
-                path.next();
-                break;
-            }
-        }
-
-        // サブディレクトリ内ならupする
-        else{
-
-            if( path.get_depth() >= 2 ){
-
-                path.up();
-
-                // サブディレクトリが開いてるか開いてないか
-                xml << "</subdir open=\"";
-                if( m_treeview.row_expanded( path ) ) xml << "1\" >\n";
-                else xml << "0\" >\n";
-
-                path.next();
-            }
-            else break;
-        }
-    }
-
-#ifdef _DEBUG_XML    
-    std::cout << xml.str() << std::endl;
-#endif 
-
-    return xml.str();
+    // ルート要素に属性( path, y )の値を設定
+    XML::Dom* root = m_document.get_root_element( root_name );
+    root->setAttribute( "y", y );
+    root->setAttribute( "path", path );
 }
 
 
 //
 // XML -> tree 変換
 //
-void BBSListViewBase::xml2tree( const std::string& xml )
+void BBSListViewBase::xml2tree( const std::string& root_name, const std::string& xml )
 {
-    JDLIB::Regex regex;
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::xml2tree\n";
+#endif
 
     m_ready_tree = false;
     m_treestore->clear();
-    
-    std::list< std::string > lines = MISC::get_lines( xml );
-    if( lines.empty() ) return;
 
 #if GTKMMVER >= 280
     m_treeview.unset_model();
 #endif
 
-    // XML を解析してツリーを作る
-    std::list< Gtk::TreePath > list_path_expand;
-    Gtk::TreeModel::Row row;
-    int y = -1;
-    std::string focused_path;
-    int level = 0, type;
-    std::string url, name;
-    std::list< std::string >::iterator it;
-    for( it = lines.begin(); it != lines.end(); ++it ){
-
-        std::string& line = *( it );
-
-        // 座標
-        if( y == -1 && regex.exec( "< *pos +y=\"([^\"]*)\"( +path=\"([^\"]*)\")? */>", line, 0, true ) ){
-
-            y = atoi( regex.str( 1 ).c_str() );
-            focused_path = regex.str( 3 );
+    // 新規に文字列からDOMノードツリーを作成する場合
+    if( ! xml.empty() ) m_document.init( xml );
 
 #ifdef _DEBUG
-            std::cout << "y = " << y << " path = " << focused_path << std::endl;
+    std::cout << " ルートノード名=" << root_name;
+    std::cout << " 子ノード数=" << m_document.childNodes().size() << std::endl;
 #endif
-        }
-        
-        // タイプ別
-        else if( ( type = XML::get_type( line, url, name ) ) != TYPE_UNKNOWN ){
 
-            // 板やスレ
-            if( type != TYPE_DIR ){
-                Gtk::TreeModel::Row row_tmp = *( m_treestore->append( row.children() ) );
-                setup_row( row_tmp, url, name, type );
-            }
+    // 開いてるツリーの格納用
+    std::list< Gtk::TreePath > list_path_expand;
 
-            // サブディレクトリ
-            else{
-
-                // レベル0ならルートに追加
-                if( level == 0 ) row = *( m_treestore->append() );
-
-                // サブディレクトリの中にサブディレクトリを作る
-                else row = *( m_treestore->append( row.children() ) );
-
-                setup_row( row, std::string(), name,  type );
-
-                ++level;
-            }
-        }
-        
-        // サブディレクトリ終わり
-        else if( regex.exec( "</subdir +open=\"(.*)\" *>", line, 0, true ) ){
-
-            // expand
-            if( regex.str( 1 ) == "1" ){
-                Gtk::TreePath path = GET_PATH( row );
-                list_path_expand.push_back( path );
-            }
-
-            // 終わり
-            if( level == 0 ) break;
-
-            row = *( row.parent() );
-            --level;
-        }
-    }
+    // Domノードから Gtk::TreeStore をセット
+    m_document.set_treestore( m_treestore, root_name, list_path_expand );
 
 #if GTKMMVER >= 280
     m_treeview.set_model( m_treestore );
@@ -2018,25 +1969,37 @@ void BBSListViewBase::xml2tree( const std::string& xml )
 
     // ディレクトリオープン
     std::list< Gtk::TreePath >::iterator it_path = list_path_expand.begin();
-    for( ; it_path != list_path_expand.end(); ++it_path ){
+    while( it_path != list_path_expand.end() )
+    {
         m_treeview.expand_parents( *it_path );
         m_treeview.expand_row( *it_path, false );
+        ++it_path;
     }
 
-    // 前回閉じた位置まで移動
-    if( !focused_path.empty() ){
-        Gtk::TreePath path = Gtk::TreePath( focused_path );
-        if( m_treeview.get_row( path ) ){
-            m_treeview.set_cursor( path );
-        }
-        else m_treeview.get_selection()->unselect_all();
-    }
-    else m_treeview.get_selection()->unselect_all();
+    // ルート要素を取り出す
+    XML::Dom* root = m_document.get_root_element( root_name );
 
-    if( y != -1 ){
-        // この段階ではまだスクロールバーが表示されてない時があるのでclock_in()で移動する
-        m_jump_y = y;
-    }
+	// ルート要素から属性( path, y )の値を取得
+	std::string focused_path = root->getAttribute( "path" );
+	int y = atoi( root->getAttribute( "y" ).c_str() );
+
+	// 前回閉じた位置まで移動
+	if( focused_path.empty() )
+	{
+		focused_path = "0";
+		y = 0;
+	}
+
+	Gtk::TreePath path = Gtk::TreePath( focused_path );
+	if( m_treeview.get_row( path ) ) m_treeview.set_cursor( path );
+	else
+	{
+		m_treeview.get_selection()->unselect_all();
+		y = 0;
+	}
+
+	// この段階ではまだスクロールバーが表示されてない時があるのでclock_in()で移動する
+	m_jump_y = y;
 
     m_ready_tree = true;
 }
@@ -2049,6 +2012,7 @@ void BBSListViewBase::xml2tree( const std::string& xml )
 void BBSListViewBase::update_urls()
 {
     if( ! m_ready_tree ) return;
+
     if( m_treestore->children().empty() ) return; 
    
 #ifdef _DEBUG
@@ -2122,13 +2086,19 @@ void BBSListViewBase::update_urls()
 //
 // m_search_invert = true なら前方検索
 //
-void BBSListViewBase::search()
+void BBSListViewBase::slot_active_search()
 {
+    if( m_toolbar.m_entry_search.completion() ) return;
+
     JDLIB::Regex regex;
 
-    focus_view();
+    CORE::core_set_command( "set_mginfo", "", "" );
+
     std::string query = m_toolbar.m_entry_search.get_text();
-    if( query.empty() ) return;
+    if( query.empty() ){
+        focus_view();
+        return;
+    }
     
     Gtk::TreePath path = m_treeview.get_current_path();
     if( !m_treeview.get_row( path ) ){
@@ -2146,9 +2116,10 @@ void BBSListViewBase::search()
     Gtk::TreePath path_start = path;
 
 #ifdef _DEBUG
-    std::cout << "BBSListViewBase::search() path = " << path.to_string() << " query = " << query << std::endl;
+    std::cout << "BBSListViewBase::slot_active_search() path = " << path.to_string() << " query = " << query << std::endl;
 #endif
-    
+
+    bool hit = false;
     for(;;){
 
         // 後方
@@ -2163,19 +2134,26 @@ void BBSListViewBase::search()
             else path = m_treeview.prev_path( path, false );
         }
 
-        if( path == path_start ) break;
-        
         Glib::ustring name = path2name( path );
         Glib::ustring url = path2url( path );
 
-        if( regex.exec( query, name, 0, true, true, true ) || regex.exec( query, url, 0, true ) ){
+        if( regex.exec( query, name, 0, true, true, true ) || regex.exec( query, url, 0, true ) ) hit = true;
+
+        // 一周したら終わり
+        if( path == path_start ) break;
+
+        // カーソル移動
+        if( hit ){
             m_treeview.expand_parents( path );
             m_treeview.scroll_to_row( path, 0.1 );
             m_treeview.set_cursor( path );
             show_status();
-            return;
+            break;
         }
     }
+
+    if( hit ) focus_view();
+    else CORE::core_set_command( "set_mginfo", "", "検索結果： ヒット無し" );
 }
 
 
@@ -2183,7 +2161,7 @@ void BBSListViewBase::search()
 void BBSListViewBase::slot_push_up_search()
 {
     m_search_invert = true;
-    search();
+    slot_active_search();
 }
 
 
@@ -2192,7 +2170,7 @@ void BBSListViewBase::slot_push_up_search()
 void BBSListViewBase::slot_push_down_search()
 {
     m_search_invert = false;
-    search();
+    slot_active_search();
 }
 
 
@@ -2209,14 +2187,19 @@ void BBSListViewBase::slot_entry_operate( int controlid )
 // ラベルのコンボボックスの表示が変わった
 void BBSListViewBase::slot_combo_changed()
 {
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::slot_combo_changed url = " << get_url()
+              << " combo = " << get_toolbar().get_combo() << std::endl;
+#endif
+
     switch( get_toolbar().get_combo() ){
 
         case COMBO_BBSLIST:
-            CORE::core_set_command( "switch_sidebar", URL_BBSLISTVIEW );
+            if( get_url() != URL_BBSLISTVIEW ) CORE::core_set_command( "switch_sidebar", URL_BBSLISTVIEW );
             break;
 
         case COMBO_FAVORITE:
-            CORE::core_set_command( "switch_sidebar", URL_FAVORITEVIEW );
+            if( get_url() != URL_FAVORITEVIEW ) CORE::core_set_command( "switch_sidebar", URL_FAVORITEVIEW );
             break;
     }
 }
