@@ -6,6 +6,8 @@
 #include "boardadmin.h"
 #include "boardview.h"
 
+#include "skeleton/msgdiag.h"
+
 #include "jdlib/miscutil.h"
 #include "jdlib/jdregex.h"
 
@@ -22,6 +24,8 @@
 #include "controlid.h"
 #include "prefdiagfactory.h"
 #include "httpcode.h"
+#include "colorid.h"
+#include "fontid.h"
 
 #include "icons/iconmanager.h"
 
@@ -30,15 +34,6 @@
 
 using namespace BOARD;
 
-#define COLUMN_TITLE_ID    "ID"
-#define COLUMN_TITLE_NAME  "タイトル"
-#define COLUMN_TITLE_RES   "レス"
-#define COLUMN_TITLE_LOAD  "取得"
-#define COLUMN_TITLE_NEW   "新着"
-#define COLUMN_TITLE_SINCE "since"
-#define COLUMN_TITLE_WRITE "最終書込"
-#define COLUMN_TITLE_SPEED "速度"
-
 
 // row -> path
 #define GET_PATH( row ) m_liststore->get_path( row )
@@ -101,19 +96,19 @@ m_treeview.append_column( *col ); \
 }while(0)
 
 
-
 BoardView::BoardView( const std::string& url,const std::string& arg1, const std::string& arg2 )
     : SKELETON::View( url ),
-      m_treeview( CONFIG::get_fontname_tree_board(), CONFIG::get_color_back_tree_board() ),
+      m_treeview( CONFIG::get_fontname( FONT_BOARD ), COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN ),
       m_col( COL_NUM_COL ),
       m_previous_col( COL_NUM_COL ),
       m_sortmode( SORTMODE_ASCEND ),
-      m_previous_sortmode( false )
+      m_previous_sortmode( false ),
+      m_toolbar( SESSION::get_show_board_toolbar() )
 {
     m_scrwin.add( m_treeview );
     m_scrwin.set_policy( Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS );
 
-    m_toolbar.m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BoardView::search ) );
+    m_toolbar.m_entry_search.signal_activate().connect( sigc::mem_fun( *this, &BoardView::slot_active_search ) );
     m_toolbar.m_button_close.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::close_view ) );
     m_toolbar.m_button_reload.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::reload ) );
     m_toolbar.m_button_stop.signal_clicked().connect( sigc::mem_fun( *this, &BoardView::stop ) );
@@ -151,7 +146,7 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
 #endif
 
     // columnのappend
-    APPEND_COLUMN( " ", m_columns.m_col_mark );
+    APPEND_COLUMN( COLUMN_TITLE_MARK, m_columns.m_col_mark );
     APPEND_COLUMN( COLUMN_TITLE_ID, m_columns.m_col_id );
     APPEND_COLUMN( COLUMN_TITLE_NAME, m_columns.m_col_subject );
     APPEND_COLUMN( COLUMN_TITLE_RES, m_columns.m_col_res );
@@ -160,16 +155,19 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     APPEND_COLUMN( COLUMN_TITLE_SINCE, m_columns.m_col_since );
     APPEND_COLUMN( COLUMN_TITLE_WRITE, m_columns.m_col_write );
     APPEND_COLUMN( COLUMN_TITLE_SPEED, m_columns.m_col_speed );
-    m_treeview.set_column_for_height( 2 );
 
     // サイズを調整しつつソートの設定
     for( guint i = 0; i < COL_VISIBLE_END; i++ ){
         
+        int id = get_title_id( i );
+        if( id < 0 ) continue;
+
         Gtk::TreeView::Column* column = m_treeview.get_column( i );
+        if( ! column ) continue;
 
         int width = 0;
 
-        switch( i ){
+        switch( id ){
 
         case COL_MARK:
             width = SESSION::col_mark();
@@ -181,6 +179,7 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
 
         case COL_SUBJECT:
             width = SESSION::col_subject();
+            m_treeview.set_column_for_height( id );
             break;
 
         case COL_RES:
@@ -215,14 +214,53 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
         column->set_clickable( true );        
 
         // ヘッダをクリックしたときに呼ぶslot
-        column->signal_clicked().connect( sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_col_clicked ), i ) );
+        column->signal_clicked().connect( sigc::bind< int >( sigc::mem_fun( *this, &BoardView::slot_col_clicked ), id ) );
 
-        // subjectの背景色設定
-        if( i == COL_SUBJECT ){
-            Gtk::CellRendererText* rentext = dynamic_cast< Gtk::CellRendererText* >( column->get_first_cell_renderer() );
-            if( rentext ){
-                rentext->property_cell_background().set_value( "yellow" );
-                column->add_attribute( *rentext, "cell_background_set", COL_DRAWBG ); 
+        // ヘッダの位置
+        switch( id ){
+            case COL_MARK:
+                column->set_alignment( 0.5 );
+                break;
+
+            case COL_ID:
+            case COL_RES:
+            case COL_STR_LOAD:
+            case COL_STR_NEW:
+            case COL_SPEED:
+                column->set_alignment( 1.0 );
+                break;
+
+            default:
+                column->set_alignment( 0.0 );
+                break;
+        }
+
+        Gtk::CellRenderer *cell = column->get_first_cell_renderer();
+
+        // 実際の描画の際に cellrendere のプロパティをセットするスロット関数
+        if( cell ) column->set_cell_data_func( *cell, sigc::mem_fun( *this, &BoardView::slot_cell_data ) );
+
+        Gtk::CellRendererText* rentext = dynamic_cast< Gtk::CellRendererText* >( cell );
+        if( rentext ){
+
+            // 列間スペース
+            rentext->property_xpad() = 4;
+
+            // 行間スペース
+            rentext->property_ypad() = CONFIG::get_tree_ypad();;
+
+            // 文字位置
+            switch( id ){
+                case COL_ID:
+                case COL_RES:
+                case COL_STR_LOAD:
+                case COL_STR_NEW:
+                case COL_SPEED:
+                    rentext->property_xalign() = 1.0;
+                    break;
+
+                default:
+                    rentext->property_xalign() = 0.0;
             }
         }
     }
@@ -355,7 +393,7 @@ BoardView::BoardView( const std::string& url,const std::string& arg1, const std:
     set_enable_autoreload( true );
 
     // コントロールモード設定
-    get_control().set_mode( CONTROL::MODE_BOARD );
+    get_control().add_mode( CONTROL::MODE_BOARD );
 }
 
 
@@ -380,6 +418,34 @@ const std::string BoardView::url_for_copy()
 
 
 
+//
+// i列目のIDを取得
+//
+// 失敗の時は-1を変えす
+//
+int BoardView::get_title_id( int col )
+{
+    Gtk::TreeView::Column* column = m_treeview.get_column( col );
+    if( ! column ) return -1;
+
+    std::string title = column->get_title();
+    int id = -1;
+
+    if( title == COLUMN_TITLE_MARK ) id = COL_MARK;
+    else if( title == COLUMN_TITLE_ID ) id = COL_ID;
+    else if( title == COLUMN_TITLE_NAME ) id = COL_SUBJECT;
+    else if( title == COLUMN_TITLE_RES ) id = COL_RES;
+    else if( title == COLUMN_TITLE_LOAD ) id = COL_STR_LOAD;
+    else if( title == COLUMN_TITLE_NEW ) id = COL_STR_NEW;
+    else if( title == COLUMN_TITLE_SINCE ) id = COL_SINCE;
+    else if( title == COLUMN_TITLE_WRITE ) id = COL_WRITE;
+    else if( title == COLUMN_TITLE_SPEED ) id = COL_SPEED;
+
+    return id;
+}
+
+
+
 //
 // 列の幅の大きさを取得してセッションデータベース更新
 //
@@ -391,13 +457,16 @@ void BoardView::save_column_width()
 
     for( guint i = 0; i < COL_VISIBLE_END; i++ ){
         
+        int id = get_title_id( i );
+        if( id < 0 ) continue;
+
         Gtk::TreeView::Column* column = m_treeview.get_column( i );
 
         int width = 0;
         if( column ) width = column->get_width();
-        if( !width ) continue;
+        if( ! width ) continue;
 
-        switch( i ){
+        switch( id ){
 
         case COL_MARK:
             SESSION::set_col_mark( width );
@@ -440,11 +509,38 @@ void BoardView::save_column_width()
    
 
 
+//
+// 実際の描画の際に cellrendere のプロパティをセットするスロット関数
+//
+void BoardView::slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it )
+{
+    Gtk::TreeModel::Row row = *it;
+    Gtk::TreePath path = m_liststore->get_path( row );
+
+#ifdef _DEBUG
+    std::cout << "BoardView::slot_cell_data path = " << path.to_string() << std::endl;
+#endif
+
+    // ハイライト色
+    if( row[ m_columns.m_col_drawbg ] ){
+        cell->property_cell_background() = CONFIG::get_color( COLOR_BACK_HIGHLIGHT_TREE );
+        cell->property_cell_background_set() = true;
+    }
+
+    else m_treeview.slot_cell_data( cell, it );
+}
+
+
+
 //
 // ソート実行
 //
 void BoardView::exec_sort()
 {
+#ifdef _DEBUG
+    std::cout << "BoardView::exec_sort\n";
+#endif
+
     if( m_col < 0 || m_col >= COL_VISIBLE_END ){
         m_col = COL_ID;
         m_sortmode = SORTMODE_ASCEND;
@@ -452,7 +548,6 @@ void BoardView::exec_sort()
 
     m_liststore->set_sort_column( -2, Gtk::SORT_ASCENDING );
     m_liststore->set_sort_column( m_col, Gtk::SORT_ASCENDING );
-    CORE::core_set_command( "switch_board" );
 }
 
 
@@ -494,6 +589,7 @@ void BoardView::slot_col_clicked( int col )
     DBTREE::board_set_view_sort_pre_mode( get_url(), m_previous_sortmode );
 
     exec_sort();
+    focus_view();
 }
 
 
@@ -659,10 +755,19 @@ void BoardView::clock_in()
 //
 void BoardView::reload()
 {
+    // オフライン
+    if( ! SESSION::is_online() ){
+        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+        mdiag.run();
+        return;
+    }
+
     // オートリロードのカウンタを0にする
     View::reset_autoreload_counter();
 
     show_view();
+
+    // 板履歴更新
     CORE::core_set_command( "set_history_board", get_url() );
 }
 
@@ -737,8 +842,9 @@ void BoardView::redraw_view()
     m_previous_sortmode = DBTREE::board_view_sort_pre_mode( get_url() );
 
     exec_sort();
-
     goto_top();
+
+    if( BOARD::get_admin()->has_focus() ) focus_view();
 }
 
 
@@ -748,8 +854,8 @@ void BoardView::redraw_view()
 //
 void BoardView::relayout()
 {
-    m_treeview.init_color( CONFIG::get_color_back_tree_board() );
-    m_treeview.init_font( CONFIG::get_fontname_tree_board() );
+    m_treeview.init_color( COLOR_CHAR_BOARD, COLOR_BACK_BOARD, COLOR_BACK_BOARD_EVEN );
+    m_treeview.init_font( CONFIG::get_fontname( FONT_BOARD ) );
 }
 
 
@@ -800,6 +906,8 @@ void BoardView::update_view()
             row[ m_columns.m_col_since_t ] = art->get_since_time();
             row[ m_columns.m_col_id_dat ] = art->get_id();
 
+            row[ m_columns.m_col_drawbg ] = false;
+
             update_row_common( art, row, id );
 
             // 更新があるかチェック
@@ -835,6 +943,10 @@ void BoardView::update_view()
 
 void BoardView::focus_view()
 {
+#ifdef _DEBUG
+    std::cout << "BoardView::focus_view\n";
+#endif
+
     m_treeview.grab_focus();
 }
 
@@ -848,6 +960,10 @@ void BoardView::focus_out()
 }
 
 
+
+//
+// 閉じる
+//
 void BoardView::close_view()
 {
     BOARD::get_admin()->set_command( "close_currentview" );
@@ -965,7 +1081,8 @@ void BoardView::operate_view( const int& control )
 
         case CONTROL::Delete:
         {
-            Gtk::MessageDialog mdiag( "選択した行のログを削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+            SKELETON::MsgDiag mdiag( NULL, "選択した行のログを削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
+            mdiag.set_default_response( Gtk::RESPONSE_OK );
             if( mdiag.run() != Gtk::RESPONSE_OK ) return;
             delete_view();
             break;
@@ -999,6 +1116,11 @@ void BoardView::operate_view( const int& control )
         case CONTROL::ShowSideBar:
             CORE::core_set_command( "toggle_sidebar" );
             break;
+
+            // メニューバー表示/非表示
+        case CONTROL::ShowMenuBar:
+            CORE::core_set_command( "toggle_menubar" );
+            break;
     }
 }
 
@@ -1075,6 +1197,16 @@ void BoardView::scroll_right()
 
 
 
+//
+// ツールバー表示切り替え
+//
+void BoardView::toggle_toolbar()
+{
+    if( SESSION::get_show_board_toolbar() ) m_toolbar.show_toolbar();
+    else m_toolbar.hide_toolbar();
+}
+
+
 //
 // 上へ移動
 //
@@ -1185,23 +1317,25 @@ void BoardView::update_row_common( DBTREE::ArticleBase* art, Gtk::TreeModel::Row
 {
     if( art->empty() ) return;
 
+    const int load = art->get_number_load();
+    const int res = art->get_number();
+
     // タイトル、レス数、抽出
     row[ m_columns.m_col_subject ] = art->get_subject();
-    row[ m_columns.m_col_res ] = art->get_number();
-    row[ m_columns.m_col_drawbg ] = false;
+    row[ m_columns.m_col_res ] = res;
 
     // 読み込み数
 
-    if( art->get_number_load() ){
+    if( load ){
         const int tmpsize = 32;
         char tmp[ tmpsize ];
-        snprintf( tmp, tmpsize, "%d", art->get_number_load() );
+        snprintf( tmp, tmpsize, "%d", load );
         row[ m_columns.m_col_str_load ] = tmp;
-        snprintf( tmp, tmpsize, "%d", art->get_number() - art->get_number_load() );
+        snprintf( tmp, tmpsize, "%d", res - load );
         row[ m_columns.m_col_str_new ] = tmp;
 
-        row[ m_columns.m_col_load ] = art->get_number_load();
-        row[ m_columns.m_col_new ] = art->get_number() - art->get_number_load();
+        row[ m_columns.m_col_load ] = load;
+        row[ m_columns.m_col_new ] = res - load;
     }
     else{
         row[ m_columns.m_col_str_load ] = "";
@@ -1292,7 +1426,7 @@ bool BoardView::slot_button_press( GdkEventButton* event )
     m_dblclick = false;
     if( event->type == GDK_2BUTTON_PRESS ) m_dblclick = true; 
 
-    CORE::core_set_command( "switch_board" );
+    BOARD::get_admin()->set_command( "switch_admin" );
 
     return true;
 }
@@ -1407,17 +1541,17 @@ bool BoardView::slot_motion_notify( GdkEventMotion* event )
 //
 bool BoardView::slot_key_press( GdkEventKey* event )
 {
-    int key = get_control().key_press( event );
+    m_pressed_key = get_control().key_press( event );
 
-    if( key != CONTROL::None ){
+    if( m_pressed_key != CONTROL::None ){
 
         // キー入力でスレを開くとkey_releaseイベントがboadviewが画面から
         // 消えてから送られてWIDGET_REALIZED_FOR_EVENT assertionが出るので
         // OpenArticle(Tab)は slot_key_release() で処理する
-        if( key == CONTROL::OpenArticle ) return true;
-        if( key == CONTROL::OpenArticleTab ) return true;
+        if( m_pressed_key == CONTROL::OpenArticle ) return true;
+        if( m_pressed_key == CONTROL::OpenArticleTab ) return true;
 
-        operate_view( key );
+        operate_view( m_pressed_key );
     }
     else release_keyjump_key( event->keyval );
 
@@ -1432,11 +1566,15 @@ bool BoardView::slot_key_release( GdkEventKey* event )
 {
     int key = get_control().key_press( event );
 
-    // キー入力でスレを開くとkey_releaseイベントがboadviewが画面から
-    // 消えてから送られてWIDGET_REALIZED_FOR_EVENT assertionが出るので
-    // OpenArticle(Tab)はここで処理する
-    if( key == CONTROL::OpenArticle ) operate_view( key );
-    if( key == CONTROL::OpenArticleTab ) operate_view( key );
+    // 押したキーと違うときは処理しない
+    if( key == m_pressed_key ){
+
+        // キー入力でスレを開くとkey_releaseイベントがboadviewが画面から
+        // 消えてから送られてWIDGET_REALIZED_FOR_EVENT assertionが出るので
+        // OpenArticle(Tab)はここで処理する
+        if( key == CONTROL::OpenArticle ) operate_view( key );
+        if( key == CONTROL::OpenArticleTab ) operate_view( key );
+    }
    
     return true;
 }
@@ -1677,17 +1815,15 @@ std::string BoardView::path2daturl( const Gtk::TreePath& path )
 //
 bool BoardView::drawout()
 {
-    bool find = false;
+    if( m_toolbar.m_entry_search.completion() ) return false;
+
+    int hit = 0;
     bool reset = false;
 
-    focus_view();
     std::string query = m_toolbar.m_entry_search.get_text();
 
     // 空の時はリセット
-    if( query.empty() ){
-        find = true;
-        reset = true;
-    }
+    if( query.empty() ) reset = true;
 
     if( m_pre_query == query ) return false;
     m_pre_query = query;
@@ -1710,7 +1846,7 @@ bool BoardView::drawout()
         if( reset ) row[ m_columns.m_col_drawbg ] = false;
         else if( regex.exec( query, subject, 0, true, true, true ) ){
             row[ m_columns.m_col_drawbg ] = true;
-            find = true;
+            ++hit;
 
 #ifdef _DEBUG
             std::cout << subject << " " << row[ m_columns.m_col_mark_val ] << std::endl;
@@ -1720,7 +1856,17 @@ bool BoardView::drawout()
         else row[ m_columns.m_col_drawbg ] = false;
     }
 
-    if( find ) redraw_view();
+    if( reset || hit ) redraw_view();
+
+    if( reset ){
+        focus_view();
+        CORE::core_set_command( "set_mginfo", "", "" );
+    }
+    else if( ! hit ) CORE::core_set_command( "set_mginfo", "", "検索結果： ヒット無し" );
+    else{
+        focus_view();
+        CORE::core_set_command( "set_mginfo", "", "検索結果： " + MISC::itostr( hit ) + "件" );
+    }
 
     return true;
 }
@@ -1730,8 +1876,10 @@ bool BoardView::drawout()
 //
 // 検索移動
 //
-void BoardView::search()
+void BoardView::slot_active_search()
 {
+    if( m_toolbar.m_entry_search.completion() ) return;
+
     if( drawout() ) return;
 
     focus_view();
@@ -1786,7 +1934,7 @@ void BoardView::search()
 void BoardView::slot_push_up_search()
 {
     m_search_invert = true;
-    search();
+    slot_active_search();
 }
 
 
@@ -1795,13 +1943,15 @@ void BoardView::slot_push_up_search()
 void BoardView::slot_push_down_search()
 {
     m_search_invert = false;
-    search();
+    slot_active_search();
 }
 
 
 // キャッシュ検索
 void BoardView::slot_search_cache()
 {
+    if( m_toolbar.m_entry_search.completion() ) return;
+
     std::string query = m_toolbar.m_entry_search.get_text();
     CORE::core_set_command( "open_article_searchcache", get_url() , query, "false" );
 }
@@ -1822,7 +1972,7 @@ void BoardView::slot_entry_operate( int controlid )
 //
 void BoardView::slot_push_preferences()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( CORE::PREFDIAG_BOARD, get_url() );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_BOARD, get_url() );
     pref->run();
     delete pref;
 }
@@ -1836,7 +1986,7 @@ void BoardView::slot_preferences_article()
     if( m_path_selected.empty() ) return;
     std::string url = path2daturl( m_path_selected );
 
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( CORE::PREFDIAG_ARTICLE, url );
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( NULL, CORE::PREFDIAG_ARTICLE, url );
     pref->run();
     delete pref;
 }
