@@ -30,6 +30,9 @@ namespace BOARD
         // ダブルクリック状態
         bool m_dblclick;
 
+        // 押したキー
+        int m_pressed_key;
+
         // ソートで使う変数
         int m_col;
         int m_previous_col;
@@ -71,6 +74,7 @@ namespace BOARD
         virtual void goto_num( int num );
         virtual void scroll_left();
         virtual void scroll_right();
+        virtual void toggle_toolbar();
 
         void row_up();
         void row_down();
@@ -83,8 +87,11 @@ namespace BOARD
 
     private:
 
+        int get_title_id( int col );
         void save_column_width();
 
+        void slot_cell_data( Gtk::CellRenderer* cell, const Gtk::TreeModel::iterator& it );
+
         // ソート用
         void exec_sort();
         void slot_col_clicked( int col );
@@ -121,7 +128,7 @@ namespace BOARD
 
         // 検索
         bool drawout();
-        void search();
+        void slot_active_search();
         void slot_push_down_search();
         void slot_push_up_search();
         void slot_entry_operate( int controlid );
