@@ -8,7 +8,7 @@
 #include <gtkmm.h>
 
 #include "skeleton/imgbutton.h"
-#include "skeleton/entry.h"
+#include "skeleton/compentry.h"
 
 #include "icons/iconmanager.h"
 
@@ -17,14 +17,15 @@
 
 namespace BOARD
 {
-    class BoardToolBar : public Gtk::ScrolledWindow
+    class BoardToolBar : public Gtk::VBox
     {
 
         friend class BoardView;
 
+        Gtk::ScrolledWindow m_scrwin;
         Gtk::HBox m_buttonbar;
-
-        SKELETON::JDEntry m_entry_search;
+        bool m_toolbar_shown;
+        SKELETON::SearchEntry m_entry_search;
         SKELETON::ImgButton m_button_close;
         SKELETON::ImgButton m_button_reload;
         SKELETON::ImgButton m_button_delete;
@@ -38,7 +39,29 @@ namespace BOARD
 
         Gtk::Tooltips m_tooltip;
 
-        BoardToolBar() :
+        // ツールバーを表示
+        void show_toolbar()
+        {
+            if( ! m_toolbar_shown ){
+                pack_start( m_scrwin, Gtk::PACK_SHRINK );
+                show_all_children();
+                m_toolbar_shown = true;
+            }
+        }
+
+        // ツールバーを隠す
+        void hide_toolbar()
+        {
+            if( m_toolbar_shown ){
+                remove( m_scrwin );
+                show_all_children();
+                m_toolbar_shown = false;
+            }
+        }
+
+
+        BoardToolBar( bool show_bar ) :
+        m_toolbar_shown( false ),
         m_button_close( Gtk::Stock::CLOSE ),
         m_button_reload( Gtk::Stock::REFRESH ),
         m_button_delete( Gtk::Stock::DELETE ),
@@ -62,24 +85,26 @@ namespace BOARD
             m_tooltip.set_tip( m_button_new_article, CONTROL::get_label_motion( CONTROL::NewArticle ) );
             m_tooltip.set_tip( m_button_preferences, CONTROL::get_label_motion( CONTROL::Property )  );
         
+            m_buttonbar.pack_start( m_button_new_article, Gtk::PACK_SHRINK );
             m_buttonbar.pack_start( m_entry_search );
             m_buttonbar.pack_end( m_button_close, Gtk::PACK_SHRINK );    
             m_buttonbar.pack_end( m_button_delete, Gtk::PACK_SHRINK );
             m_buttonbar.pack_end( m_button_preferences, Gtk::PACK_SHRINK );
             m_buttonbar.pack_end( m_button_favorite, Gtk::PACK_SHRINK );
-            m_buttonbar.pack_end( m_button_new_article, Gtk::PACK_SHRINK );
             m_buttonbar.pack_end( m_button_stop, Gtk::PACK_SHRINK );
             m_buttonbar.pack_end( m_button_reload, Gtk::PACK_SHRINK );
             m_buttonbar.pack_end( m_button_search_cache, Gtk::PACK_SHRINK );
             m_buttonbar.pack_end( m_button_up_search, Gtk::PACK_SHRINK );
             m_buttonbar.pack_end( m_button_down_search, Gtk::PACK_SHRINK );
 
-            m_entry_search.set_mode( CONTROL::MODE_BOARD );
+            m_entry_search.add_mode( CONTROL::MODE_BOARD );
 
             m_buttonbar.set_border_width( 1 );
-            add( m_buttonbar );
-            set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_NEVER );
+            m_scrwin.add( m_buttonbar );
+            m_scrwin.set_policy( Gtk::POLICY_NEVER, Gtk::POLICY_NEVER );
+
             set_size_request( 8 );
+            if( show_bar ) show_toolbar();
         }
 
     };
