@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 //
 // マウスボタン設定
 //
@@ -17,11 +17,12 @@ namespace CONFIG
         ButtonConfig();
         virtual ~ButtonConfig();
 
-        // 中ボタンでタブで開くか
-        bool tab_midbutton();
+        bool tab_midbutton(); // 中ボタンでタブで開くか
+        void toggle_tab_button(); // タブで開くボタンを入れ替える
+
+        bool is_popup_warpmode(); // ポップアップ表示の時にクリックでワープするか
+        void toggle_popup_warpmode(); // ポップアップ表示の時にクリックでワープする
 
-        // タブで開くボタンを入れ替える
-        void toggle_tab_button();
 
       private:
 
