@@ -78,6 +78,7 @@ void KeyConfig::load_conf()
 
     SETMOTION( "ShowPopupMenu", "Shift+F10 Ctrl+m" );
 
+    SETMOTION( "ShowMenuBar", "F8" );
     SETMOTION( "ShowSideBar", "F9" );
 
     SETMOTION( "Home", "Home g <" );
@@ -135,9 +136,9 @@ void KeyConfig::load_conf()
     SETMOTION( "CancelWrite", "Alt+q" );
     SETMOTION( "ExecWrite", "Alt+w" ); 
 
-    // EDIT
-    SETMOTION( "UndoEdit", "Ctrl+/ Ctrl+z" );
+    SETMOTION( "FocusWrite", "Tab" ); 
 
+    // EDIT
     SETMOTION( "HomeEdit", "" );
     SETMOTION( "EndEdit", "" );
 
@@ -147,6 +148,11 @@ void KeyConfig::load_conf()
     SETMOTION( "LeftEdit", "" );
 
     SETMOTION( "DeleteEdit", "" );
+    SETMOTION( "BackspEdit", "" );
+
+    SETMOTION( "UndoEdit", "Ctrl+/ Ctrl+z" );
+
+    SETMOTION( "InputAA", "Alt+a" );
 }
 
 
