@@ -11,8 +11,12 @@
 #include <list>
 #include <string>
 
+#include "skeleton/dispatchable.h"
 #include "skeleton/imgbutton.h"
 #include "skeleton/hpaned.h"
+#include "skeleton/vpaned.h"
+#include "skeleton/notebook.h"
+#include "skeleton/vbox.h"
 
 #include "command_args.h"
 
@@ -53,36 +57,35 @@ namespace CORE
     class DND_Manager;
     class HistoryMenuThread;
     class HistoryMenuBoard;
+    class HistoryMenuClose;
 
-    class Core
+    class Core : public SKELETON::Dispatchable
     {
-        Glib::Dispatcher m_disp;
         std::list< COMMAND_ARGS > m_list_command;
         sigc::connection m_sigc_switch_page;
 
         WinMain& m_win_main;
-        
-        Gtk::VBox m_vbox_main;
+
         SKELETON::JDHPaned m_hpaned;
 
         // サイドバー
         Gtk::Widget* m_sidebar;
 
         // (縦/横) 3ペーンモード時の右側ペーン
-        Gtk::VPaned m_vpaned_r; 
-        Gtk::HPaned m_hpaned_r;
+        SKELETON::JDVPaned m_vpaned_r; 
+        SKELETON::JDHPaned m_hpaned_r;
 
         // 右ペーンで使用するwidget
-        Gtk::VBox m_vbox_article;
-        Gtk::VBox m_vbox_board;
-        Gtk::VBox m_vbox_articleboard;
-        Gtk::Notebook m_notebook;
+        SKELETON::JDVBox m_vbox_article;
+        SKELETON::JDVBox m_vbox_toolbar;
+        SKELETON::JDNotebook m_notebook;
         bool m_imagetab_shown;
+        SKELETON::JDVPaned m_vpaned_message; // 埋め込み書き込みビュー用
 
         // ツールバー
         Gtk::ScrolledWindow m_toolbar;
         Gtk::Tooltips m_tooltip;
-        Gtk::HBox m_toolbar_vbox;
+        Gtk::HBox m_toolbar_hbox;
         Gtk::Entry m_entry_url;
         SKELETON::ImgButton m_button_go;
         SKELETON::ImgButton m_button_search_cache;
@@ -98,19 +101,13 @@ namespace CORE
         // set_maintitle() 参照
         std::string m_title;
 
-        // ステータスバー
-#if GTKMMVER <= 240
-        Gtk::Statusbar m_statbar;
-#else
-        Gtk::HBox m_statbar;
-        Gtk::Label m_label_stat;
-#endif
-        Gtk::Label m_mginfo;
+        Gtk::MenuBar* m_menubar;
 
         Glib::RefPtr< Gtk::ActionGroup > m_action_group;
         Glib::RefPtr< Gtk::UIManager > m_ui_manager;
         HistoryMenuThread* m_histmenu_thread;
         HistoryMenuBoard* m_histmenu_board;
+        HistoryMenuClose* m_histmenu_close;
         bool m_enable_menuslot;
 
         // 起動中
@@ -119,6 +116,9 @@ namespace CORE
         // 初期設定中
         bool m_init;
 
+        // 終了中
+        bool m_quit;
+
     public:
 
         Core( WinMain& win_main );
@@ -136,35 +136,46 @@ namespace CORE
 
     private:
 
+        bool is_3pane();
+        bool is_all_admin_empty();
+
+        Gtk::Paned* get_rpane();
+        SKELETON::PaneControl* get_rpctrl();
+
+        void pack_widget( bool unpack );
         void create_toolbar();
 
         // 初回起動時のセットアップ
         void first_setup();
-        void show_setupdiag( const std::string& msg );
 
         void set_maintitle();
 
         void slot_activate_menubar();
 
         void slot_toggle_save_postlog();
-        void slot_toggle_strict_charwidth();
         void slot_toggle_use_mosaic();
+        void slot_toggle_use_imgview();
+        void slot_toggle_use_inlineimg();
         void slot_delete_all_images();
 
-        void slot_changefont_tree();
-        void slot_changefont_tree_board();
+        void slot_clear_privacy();
+        void slot_clear_board();
+        void slot_clear_thread();
+        void slot_clear_close();
+        void slot_clear_search();
+        void slot_clear_name();
+        void slot_clear_mail();
+
         void slot_changefont_main();
         void slot_changefont_popup();
-        void slot_changefont_message();
-
+        void slot_changefont_tree();
         void slot_changecolor_char();
-        void slot_changecolor_separator();
         void slot_changecolor_back();
-        void slot_changecolor_back_popup();
+        void slot_changecolor_char_tree();
         void slot_changecolor_back_tree();
-
-        bool open_color_diag( std::string title, const int* rgb, int* rgb_out );
-
+        bool open_color_diag( std::string title, int id );
+        
+        void slot_setup_fontcolor();
         void slot_setup_proxy();
         void slot_setup_passwd();
         void slot_setup_browser();
@@ -182,45 +193,67 @@ namespace CORE
         void slot_save_favorite();
         void slot_toggle_online();
         void slot_toggle_login2ch();
-        void slot_toggle_toolbar();
-        void slot_toggle_sidebar();
+        void toggle_menubar();
+        void toggle_sidebar();
         void slot_search_cache();
-        void slot_show_hide_leftpane( bool show );
+        void slot_show_hide_leftpane( int mode );
         void slot_toggle_toolbarpos( int pos );
+        void slot_toggle_toolbarbbslist();
+        void slot_toggle_toolbararticle();
+        void slot_toggle_toolbarboard();
         void slot_toggle_2pane();
         void slot_toggle_3pane();
         void slot_toggle_v3pane();
+        void slot_toggle_embedded_mes();
+        void slot_toggle_embedded_img();
         void slot_toggle_oldarticle();
         void slot_toggle_tabbutton();
         void slot_toggle_popupwarpmode();
+        void slot_shortmargin_popup();
         void slot_toggle_emacsmode();
         void slot_toggle_restore_views();
 
+        virtual void callback_dispatch();
+
         // coreが自前でするコマンド処理
         void exec_command();
 
         // 起動完了直後に実行する処理
         void exec_command_after_boot();
 
+        // フォーカス回復
+        void restore_focus( bool force, bool present );
+
+        // メインタイマー
         bool slot_timeout( int timer_number );
+
+        // 右ペーンのnotebookのタブの切替え
         void slot_switch_page( GtkNotebookPage*, guint page );
-        void set_toggle_view_button();
+
+        // 右ペーンのnotebookのページ番号
+        int get_right_current_page();
+
+        // 右ペーンのnotebookのページをセット
+        void set_right_current_page( int page );
+
         bool slot_focus_out_event( GdkEventFocus* ev );
         bool slot_focus_in_event( GdkEventFocus* ev );
+        bool slot_window_state_event( GdkEventWindowState* event );
         void slot_active_url();
 
         // あるadminがemptyになったので他のadminにスイッチ
         void empty_page( const std::string& url );
 
-        // あるadminののnotebookのページがスイッチした
-        void switch_page( const std::string& url );
+        void set_toggle_view_button();
+        void set_sensitive_view_button();
+        void toggle_maximize_rightpane();
+
+        void switch_article( bool present );
+        void switch_board( bool present );
+        void switch_sidebar( const std::string& url, bool present );
+        void switch_image( bool present );
+        void switch_message( bool present );
 
-        void switch_article();
-        void switch_board();
-        void switch_bbslist();
-        void switch_favorite();
-        void switch_sidebar( const std::string& url = std::string() );
-        void switch_image();
         void toggle_article();
         void switch_leftview();
         void switch_rightview();
@@ -228,6 +261,7 @@ namespace CORE
 
         void set_history_article( const std::string& url );
         void set_history_board( const std::string& url );
+        void set_history_close( const std::string& url );
 
         // 画像インジケータ表示/非表示
         void show_imagetab();
