@@ -141,13 +141,19 @@ const std::string  DBTREE::is_board_moved( const std::string& url )
 }
 
 
-const std::string& DBTREE::get_xml_bbsmenu()
+void DBTREE::update_board( const std::string& url, const std::string& name, const std::string& basicauth, bool etc )
 {
-    return get_root()->xml_bbsmenu();
+    get_root()->update_board( url, name, basicauth, etc );
 }
 
 
-const std::string& DBTREE::get_xml_etc()
+const XML::Document& DBTREE::get_xml_document()
+{
+    return get_root()->xml_document();
+}
+
+
+const std::map< std::string, std::string >& DBTREE::get_xml_etc()
 {
     return get_root()->xml_etc();
 }
@@ -425,11 +431,89 @@ std::list< std::string > DBTREE::search_cache( const std::string& url, const std
     return DBTREE::get_board( url )->search_cache( query, mode_or, stop );
 }
 
+void DBTREE::board_update_writetime( const std::string& url )
+{
+    DBTREE::get_board( url )->update_writetime();
+}
+
+const time_t DBTREE::board_write_time( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_write_time();
+}
+
+const time_t DBTREE::board_write_pass( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_write_pass();
+}
+
+const time_t DBTREE::board_samba_sec( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_samba_sec();
+}
+
+void DBTREE::board_set_samba_sec( const std::string& url, time_t sec )
+{
+    DBTREE::get_board( url )->set_samba_sec( sec );
+}
+
+time_t DBTREE::board_write_leftsec( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_write_leftsec();
+}
+
+
+/////////////////////////////////////////////////
+
+std::list< std::string > DBTREE::get_abone_list_id_board( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_list_id();
+}
+
+std::list< std::string > DBTREE::get_abone_list_name_board( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_list_name();
+}
+
+std::list< std::string > DBTREE::get_abone_list_word_board( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_list_word();
+}
+
+std::list< std::string > DBTREE::get_abone_list_regex_board( const std::string& url )
+{
+    return DBTREE::get_board( url )->get_abone_list_regex();
+}
+
+void DBTREE::reset_abone_board( const std::string& url,
+                        std::list< std::string >& ids, std::list< std::string >& names,
+                        std::list< std::string >& words, std::list< std::string >& regexs )
+{
+    DBTREE::get_board( url )->reset_abone( ids, names, words, regexs );
+}
+
+
+void DBTREE::add_abone_id_board( const std::string& url, const std::string& id )
+{
+    DBTREE::get_board( url )->add_abone_id( id );
+}
+
+void DBTREE::add_abone_name_board( const std::string& url, const std::string& name )
+{
+    DBTREE::get_board( url )->add_abone_name( name );
+}
+
+void DBTREE::add_abone_word_board( const std::string& url, const std::string& word )
+{
+    DBTREE::get_board( url )->add_abone_word( word );
+}
+
+
+/////////////////////////////////////////////////
+
 
 void DBTREE::update_abone_all_board()
 {
     DBTREE::get_root()->update_abone_all_board();
-
 }
 
 void DBTREE::update_abone_board( const std::string& url )
@@ -459,6 +543,8 @@ void DBTREE::reset_abone_thread( const std::string& url,
     DBTREE::get_board( url )->reset_abone_thread( threads, words, regexs );
 }
 
+/////////////////////////////////////////////////
+
 
 const bool DBTREE::article_is_cached( const std::string& url )
 {
@@ -526,6 +612,11 @@ const std::string DBTREE::article_write_date( const std::string& url )
     return DBTREE::get_article( url )->get_write_date();
 }
 
+// 経過時間(秒
+const time_t DBTREE::article_write_pass( const std::string& url )
+{
+    return DBTREE::get_article( url )->get_write_pass();
+}
 
 
 const int DBTREE::article_status( const std::string& url )
