@@ -21,6 +21,9 @@
 #define ICON_SIZE 32 
 
 
+// 書き込みビューのメール欄の空白
+#define JD_MAIL_BLANK "jd_mail_blank"
+
 //
 // str をクリップボードにコピー
 //
@@ -62,6 +65,7 @@ enum
 #define PROTO_BE "BE://"
 #define PROTO_ABONE "abone://"
 #define PROTO_OR "or://"
+#define PROTO_BROKEN "bloken://"
 
 
 // 仮想 URL
@@ -99,6 +103,7 @@ enum
     TYPE_DIR_END, // お気に入りの追加の時にサブディレクトリの終了の意味で使う
     TYPE_COMMENT,
     TYPE_LINK,
+    TYPE_AA,
 
     TYPE_UNKNOWN
 };
