@@ -7,19 +7,29 @@
 #ifndef _IMAGEAREAICON_H
 #define _IMAGEAREAICON_H
 
+#include "skeleton/dispatchable.h"
+
 #include "imageareabase.h"
 
 #include <pthread.h>
 
 namespace IMAGE
 {
-    class ImageAreaIcon : public ImageAreaBase
+    // m_imagetype にセットする値
+    enum
     {
-        Glib::Dispatcher m_disp;
+        IMAGE_SHOW_ICON = 0,
+        IMAGE_SHOW_INDICATOR
+    };
 
-        bool m_thread_running;
+
+    class ImageAreaIcon : public ImageAreaBase, public SKELETON::Dispatchable
+    {
         pthread_t m_thread;
+        bool m_stop;
+
         bool m_shown;
+        int m_imagetype; // dispatch()前に表示する画像を入れる
 
         Glib::RefPtr< Gdk::Pixbuf > m_pixbuf;
         Glib::RefPtr< Gdk::Pixbuf > m_pixbuf_loading;
@@ -27,15 +37,23 @@ namespace IMAGE
         Glib::RefPtr< Gdk::Pixbuf > m_pixbuf_icon;
 
       public:
+
         ImageAreaIcon( const std::string& url );
-        ~ImageAreaIcon();
+        virtual ~ImageAreaIcon();
 
         virtual void show_image();
+        void show_image_thread();
 
       private:
-        static void* launcher( void* );
-        virtual void show_image_thread();
-        void slot_set_image();
+
+        const int width_indicator();
+        const int height_indicator();
+
+        void stop();
+        void wait();
+        void show_indicator( bool loading );
+        virtual void callback_dispatch();
+        void set_image();
     };
 }
 
