@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //
 // 記事投稿クラス
@@ -48,6 +48,7 @@ namespace MESSAGE
 
       private:
         void clear();
+        void emit_sigfin();
 
         virtual void receive_data( const char* data, size_t size );
         virtual void receive_finish();
