@@ -1,4 +1,4 @@
-// ライセンス: 最新のGPL
+// ライセンス: GPL2
 
 //
 // SKELETON::PrefDiagのファクトリー
@@ -21,6 +21,9 @@ namespace CORE
         PREFDIAG_PROXY,
         PREFDIAG_GLOBALABONETHREAD,
         PREFDIAG_GLOBALABONE,
+        PREFDIAG_FONTCOLOR,
+
+        PREFDIAG_DELIMG,
 
         PREFDIAG_BOARD,
         PREFDIAG_ARTICLE,
@@ -29,7 +32,7 @@ namespace CORE
         PREFDIAG_NONE
     };
     
-    SKELETON::PrefDiag* PrefDiagFactory( int type, const std::string& url );
+    SKELETON::PrefDiag* PrefDiagFactory( Gtk::Window* parent, int type, const std::string& url );
 }
 
 #endif
