@@ -51,9 +51,6 @@ namespace SKELETON
         int m_autoreload_sec; // 何秒おきにリロードするか
         int m_autoreload_counter; // オートリロード用のカウンタ
 
-        // ポップアップメニューが表示されているかどうか
-        bool m_popupmenu_shown; 
-
         // キーボード数字入力ジャンプ用
         int m_keyjump_counter;
         int m_keyjump_num;
@@ -122,13 +119,11 @@ namespace SKELETON
 
         virtual const std::string& get_url(){ return m_url; }
         void set_url( const std::string& url ){ m_url = url; }
+        void update_host( const std::string& host );
 
         // view 上にマウスポインタがあれば true
         bool is_mouse_on_view();
 
-        // ポップアップメニューが表示されているか
-        const bool is_popupmenu_shown() const { return m_popupmenu_shown; }
-
         // 各view個別のコマンド
         virtual bool set_command( const std::string& command, const std::string& arg = std::string() ){ return true; }
 
@@ -182,6 +177,7 @@ namespace SKELETON
         virtual void scroll_down(){}
         virtual void scroll_left(){}
         virtual void scroll_right(){}
+        virtual void toggle_toolbar(){}
     };
 }
 
